# German Sentiment Classification with Bert

## Usage

## Details

Model, Process, Dataset

## Performance
| file                       | F1 micro Score |
| :------------------------- | -------------: |
| holidaycheck               |         0.9568 |
| scare                      |         0.9418 |
| filmstarts                 |         0.9021 |
| germeval                   |         0.7536 |
| PotTS                      |         0.6780 |
| emotions                   |         0.9649 |
| sb10k                      |         0.7376 |
| leipzig-deu-wikipedia-2016 |         0.9967 |
| all                        |         0.9639 |


## Cite



Twitter: @oliverguhr